/*
	Srimax Date Helper Library
*/
(function(){

	Date.monthNames		= Date.monthNames || ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
	Date.shortMonth		= Date.shortMonth || ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
	Date.dayNames		= Date.dayNames || ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
	Date.shortDays		= Date.shortDays || ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];
	Date.tinyDays		= Date.tinyDays || ['S', 'M', 'T', 'W', 'T', 'F', 'S'];
	Date.firstDayOfWeek	= Date.firstDayOfWeek || 0;
	Date.defaultFormat	= Date.defaultFormat || 'MMM dd, yyyy';

	// string replicator 
	String.prototype.times	= function(n){
		var s = '';
		for(var i=0; i<n; i++)
			s += this;
		return s;
	};

	// zero padding and trailing
	Number.prototype.zp	= function(n){
		return '0'.times(n-(this+"").length) + this;
	};

	Number.prototype.zt	= function(n){
		return this + '0'.times(n-(this+"").length);
	};

	if (!Date.prototype.format)
	{
		Date.prototype.format	= function(f, is24hr) {
			if(!this.valueOf())
				return null;

			var d	= this;

			return f.replace(/(yyyy|mmmm|mmm|mm|dddd|ddd|dd|d|hh|oo|nn|ss|ap|a\/p)/gi,
				function($1) {
					switch($1.toLowerCase()) {
						case 'yyyy':
							return d.getFullYear();
						case 'mmmm':
							return Date.monthNames[d.getMonth()];
						case 'mmm':
							return Date.shortMonth[d.getMonth()];
						case 'mm':
							return (d.getMonth()+1).zp(2);
						case 'dddd':
							return Date.dayNames[d.getDay()];
						case 'ddd':
							return Date.shortDays[d.getDay()];
						case 'dd':
							return d.getDate().zp(2);
						case 'd':
							return Date.tinyDays[d.getDay()];
						case 'hh':
							if (is24hr)
								return (h=d.getHours().zp(2));
							else
								return ((h=d.getHours()%12)?h:12).zp(2);
						case 'oo':
							return d.getHours().zp(2);
						case 'nn':
							return d.getMinutes().zp(2);
						case 'ss':
							return d.getSeconds().zp(2);
						case 'a/p':
						case 'ap':
							return d.getHours()<12?'AM':'PM';
					}
				}
			);
		};
	}

	if (!Date.prototype.addSeconds)
	{
		Date.prototype.addSeconds	= function(seconds){
			this.setSeconds(this.getSeconds() + Number(seconds));
			return this;
		};
	}

	if (!Date.prototype.addMinutes)
	{
		Date.prototype.addMinutes	= function(minutes) {
			this.setMinutes(this.getMinutes() + Number(minutes));
			return this;
		};
	}

	if (!Date.prototype.addHours)
	{
		Date.prototype.addHours	= function(hours) {
			this.setHours(this.getHours() + Number(hours));
			return this;
		};
	}

	if (!Date.prototype.addDays)
	{
		Date.prototype.addDays	= function(days) {
			this.setDate(this.getDate() + Number(days));
			return this;
		};
	}

	if (!Date.prototype.addWeeks)
	{
		Date.prototype.addWeeks	= function(weeks) {
			weeks	= Number(weeks) || 1;
			this.setDate(this.getDate() + (7*weeks));
			return this;
		};
	}

	if (!Date.prototype.addMonths)
	{
		Date.prototype.addMonths	= function(months) {
			this.setMonth(this.getMonth() + Number(months));
			return this;
		};
	}

	if (!Date.prototype.addYears)
	{
		Date.prototype.addYears	= function(years) {
			this.setFullYear(this.getFullYear() + Number(years));
			return this;
		};
	}

	if (!Date.prototype.clearTime)
	{
		Date.prototype.clearTime	= function() {
			this.setHours(0);
			this.setMinutes(0);
			this.setSeconds(0);
			this.setMilliseconds(0);
			return this;
		};
	}

	if (!Date.prototype.isAM)
	{
		Date.prototype.isAM	= function(){
			return (this.getHours() < 12);
		};
	}

	if (!Date.prototype.isPM)
	{
		Date.prototype.isPM	= function(){
			return (this.getHours() > 12);
		};
	}

	if (!Date.prototype.toInt)
	{
		Date.prototype.toInt	= function(){
			return this.getFullYear() * 10000 + (this.getMonth() + 1) * 100 + this.getDate();
		};
	}

	if (!Date.prototype.isToday)
	{
		Date.prototype.isToday	= function(timeZoneValue) {
			timeZoneValue	= timeZoneValue || Date.timeZoneValue;
			if (timeZoneValue)
			{
				var utc	= new Date().getTime() + (new Date().getTimezoneOffset() * 60000);
				return this.toInt() == new Date(utc + (3600000 * Number(timeZoneValue))).toInt();
			}

			return this.toInt() == new Date().toInt();
		};
	}

	if (!Date.prototype.isYesterday)
	{
		Date.prototype.isYesterday	= function(timeZoneValue) {
			return new Date(this).addDays(1).isToday(timeZoneValue);
		};
	}

	if (!Date.prototype.isTomorrow)
	{
		Date.prototype.isTomorrow	= function(timeZoneValue) {
			return new Date(this).addDays(-1).isToday(timeZoneValue);
		};
	}

	if (!Date.prototype.isFuture)
	{
		Date.prototype.isFuture	= function(timeZoneValue) {
			timeZoneValue	= timeZoneValue || Date.timeZoneValue;
			if (timeZoneValue)
			{
				var utc	= new Date().getTime() + (new Date().getTimezoneOffset() * 60000);
				var cur_dat = new Date(utc + (3600000 * Number(timeZoneValue)));
				cur_dat.setHours(0,0,0,0);
				cur_dat.setDate(cur_dat.getDate() + 1);
				return this.getTime() >= cur_dat.getTime();
			}

			return this.getTime() > new Date().getTime();
		};
	}

	if (!Date.prototype.isPast)
	{
		Date.prototype.isPast	= function(timeZoneValue) {
			timeZoneValue	= timeZoneValue || Date.timeZoneValue;
			if (timeZoneValue)
			{
				var utc	= new Date().getTime() + (new Date().getTimezoneOffset() * 60000);
				var cur_dat = new Date(utc + (3600000 * Number(timeZoneValue)));
				cur_dat.setHours(0,0,0,0);
				return this.getTime() < cur_dat.getTime();
			}

			return this.getTime() < new Date().getTime();
		};
	}

	if (!Date.prototype.getWeekStart)
	{
		Date.prototype.getWeekStart	= function(firstDayOfWeek){
			firstDayOfWeek	= firstDayOfWeek || Date.firstDayOfWeek;
			var ret	= new Date(this);
			return new Date(ret.setDate(ret.getDate() - Math.abs(ret.getDay() - firstDayOfWeek)));
		};
	}

	if (!Date.prototype.getWeekEnd)
	{
		Date.prototype.getWeekEnd	= function(firstDayOfWeek){
			firstDayOfWeek	= firstDayOfWeek || Date.firstDayOfWeek;
			return this.getWeekStart(firstDayOfWeek).addDays(6);
		};
	}

	if (!Date.prototype.isThisWeek)
	{
		Date.prototype.isThisWeek	= function(){
			return new Date(this) > new Date().getWeekStart() && new Date(this) < new Date().getWeekEnd();
		};
	}

	if (!Date.prototype.isLastWeek)
	{
		Date.prototype.isLastWeek	= function(){
			var dt	= new Date().addDays(-7);
			return new Date(this) > dt.getWeekStart() && new Date(this) < dt.getWeekEnd();
		};
	}

	if (!Date.prototype.isNextWeek)
	{
		Date.prototype.isNextWeek	= function(){
			var dt	= new Date().addDays(7);
			return new Date(this) > dt.getWeekStart() && new Date(this) < dt.getWeekEnd();
		};
	}

	if (!Date.prototype.isThisMonth)
	{
		Date.prototype.isThisMonth	= function(){
			return new Date(this) > new Date().getMonthStart() && new Date(this) < new Date().getMonthEnd();
		};
	}

	if (!Date.prototype.isLastMonth)
	{
		Date.prototype.isLastMonth	= function(){
			var dt	= new Date().addDays(-7);
			return new Date(this) > dt.getMonthStart() && new Date(this) < dt.getMonthEnd();
		};
	}

	if (!Date.prototype.isNextMonth)
	{
		Date.prototype.isNextMonth	= function(){
			var dt	= new Date().addDays(7);
			return new Date(this) > dt.getMonthStart() && new Date(this) < dt.getMonthEnd();
		};
	}

	if (!Date.prototype.isThisYear)
	{
		Date.prototype.isThisYear	= function(){
			return new Date(this).getFullYear() == new Date().getFullYear();
		};
	}

	if (!Date.prototype.getMonthStart)
	{
		Date.prototype.getMonthStart	= function(setToThis){
			var newDate	= new Date(this.getFullYear(), this.getMonth());
			if (setToThis)
			{
				this.setTime(newDate.getTime());
			}
			return newDate;
		};
	}

	if (!Date.prototype.getMonthEnd)
	{
		Date.prototype.getMonthEnd	= function(setToThis){
			var newDate	= new Date(this.getFullYear(), this.getMonth()+1, 0);
			if (setToThis)
			{
				this.setTime(newDate.getTime());
			}
			return newDate;
		};
	}

})();

